//
// CommonCcfConstituent -- XMM Science Analysis System
//
// Common code for the implementation of CcfConstituent
//
// Giuseppe Vacanti, XMM-SOC, European Space Agency
//   

#ifndef CommonCcfConstituent_H
#define CommonCcfConstituent_H

// C++
#include <string>

// SAS
#include "STime.h"

#include "CcfConstituent.h"
#include "DirEntryImplementation.h"

class CommonCcfConstituent : public virtual CcfConstituent, public DirEntryImplementation
{

 public:

  CommonCcfConstituent(const string name);

  virtual ~CommonCcfConstituent() {}

  virtual bool isValid() const;
  virtual string telescope() const;
  virtual string type() const;
  virtual string scope() const;
  virtual int issue() const;
  virtual string extSequence() const;
  virtual string extSequenceIdentifier() const;
  virtual STime valdate() const;
  virtual STime endvaldate() const;
  virtual bool hasEndvaldate() const;
  virtual STime date() const;
  virtual STime subdate() const;
  virtual string creator() const;
  virtual string category() const;

  virtual void print(ostream & os) const;

  virtual bool operator==(const CcfConstituent & rhs) const;
  virtual bool operator!=(const CcfConstituent & rhs) const;
  virtual bool operator<(const CcfConstituent & rhs) const;
  virtual bool operator>(const CcfConstituent & rhs) const;

 protected:

  CommonCcfConstituent();

 private:

  virtual void init();

  string _telescope, _scope, _type, _extSequence,
    _extSequenceIdentifier, _creator, _category;
  int _issue;
  STime _valdate, _evaldate, _date, _subdate, _initdate;
  bool _isValid;
  bool _init_done;
  bool _has_endvaldate;
  
};

#endif
