//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// April 04, 2000
//
#include <string>
#include <Dal.h>
#include <cifbuild.h>
#include <cifdiff.h>
#include <cifremove.h>
#include <metatask.h>
#include <param.h>
#include <CalIndexSet.h>
#include <CalIndex.h>
#include <cassert>
#include <errstr.h>
#include <fstream>

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>

int main() {
  
  const string t1 = "1998-01-01T00:00:00";
  const string t2 = "1998-02-01T00:00:00";
  const string t3 = "1998-03-01T00:00:00";
  const string cif = "ccf.cif";
  const string cif_less = "ccf_less.cif";
  const string dir = "mytestccf";

  openParameters("cifbuild");
  setParameter("withccfpath", true);
  setParameter("ccfpath",dir.c_str());
  setParameter("analysisdate",t1);
  setParameter("calindexset", cif);
  setParameter("withobservationdate",true);
  setParameter("observationdate",t1);
  setParameter("category","XMMCCF");
  task(cifbuild);

  dataSetServer->copy(cif, cif_less);

  vector<string> p(1);
  openParameters("cifremove");
  setParameter("calindexset", cif_less);
  p[0] = "XMM";
  setParameter("scopes", p);
  p[0] = "BORESIGHT";
  setParameter("types", p);
  task(cifremove);

  string cdiff("cifdiff.asc");
  openParameters("cifdiff");
  setParameter("calindex1set", cif);
  setParameter("calindex2set", cif_less);
  setParameter("withfile",true);
  setParameter("outfile", cdiff);
  task(cifdiff);

  ifstream is(cdiff.c_str());
  string line;
  getline(is,line);
  getline(is,line);
  assert(string::npos != line.find("XMM_BORESIGHT_0001.CCF"));
  getline(is,line);
  getline(is,line);
  assert(string::npos != line.find("** none **"));
  is.close();
  unlink(cdiff.c_str());
}
  
